@@ -1,8 +1,9 @@
-"""pynoticenter modules
-"""
+"""pynoticenter modules"""
 from .noticenter import PyNotiCenter, PyNotiCenterInterface
 from .options import PyNotiOptions
 from .task import PyNotiTask
 from .task_queue import PyNotiTaskQueue
 
-__version__ = "0.1.9"
+__version__ = "0.1.11"
+
+__all__ = ["PyNotiCenter", "PyNotiCenterInterface", "PyNotiOptions", "PyNotiTask", "PyNotiTaskQueue"]
